@@ -23,22 +23,24 @@ class build_py(build_py_orig):
         pass
 
 
-def artipy(dirname, setup_py):
+def artipy(dirname, setup_py, **kwargs):
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
         return {
-            'ext_modules': cythonize(find_extensions(dirname, setup_py)),
+            'ext_modules': cythonize(find_extensions(dirname, setup_py), **kwargs),
             'cmdclass': {'build_py': build_py},
         }
 
+
 def clean(setup_py):
     if os.environ.get('NO_CLEAR_ARTIPY') == "1":
         return
     else:
         dirname = os.path.split(setup_py)[0]
+        print(dirname)
         shutil.rmtree(os.path.join(dirname, "build"))
         for root, subdirs, files in os.walk(dirname):
             for fname in os.listdir(root):
                 fname.endswith('.c')
-                os.remove(fname)
\ No newline at end of file
+                os.remove(fname)
